==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/PMFORECASTOPTIONS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour PMFORECASTOPTIONS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PMFORECASTOPTIONS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENDDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BACKFILL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FORWARDFILL" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PMFORECASTOPTIONS_Type", propOrder = {
    "startdate",
    "enddate",
    "backfill",
    "forwardfill"
})
public class PMFORECASTOPTIONS_Type {

    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;
    @XmlElement(name = "ENDDATE", required = true)
    protected DATETIME enddate;
    @XmlElement(name = "BACKFILL", defaultValue = "false")
    protected String backfill;
    @XmlElement(name = "FORWARDFILL", defaultValue = "false")
    protected String forwardfill;

    /**
     * Obtient la valeur de la propriété startdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Définit la valeur de la propriété startdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

    /**
     * Obtient la valeur de la propriété enddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getENDDATE() {
        return enddate;
    }

    /**
     * Définit la valeur de la propriété enddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setENDDATE(DATETIME value) {
        this.enddate = value;
    }

    /**
     * Obtient la valeur de la propriété backfill.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBACKFILL() {
        return backfill;
    }

    /**
     * Définit la valeur de la propriété backfill.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBACKFILL(String value) {
        this.backfill = value;
    }

    /**
     * Obtient la valeur de la propriété forwardfill.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFORWARDFILL() {
        return forwardfill;
    }

    /**
     * Définit la valeur de la propriété forwardfill.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFORWARDFILL(String value) {
        this.forwardfill = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/PMFORECASTOPTIONS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for PMFORECASTOPTIONS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PMFORECASTOPTIONS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENDDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BACKFILL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FORWARDFILL" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PMFORECASTOPTIONS_Type", propOrder = {
    "startdate",
    "enddate",
    "backfill",
    "forwardfill"
})
public class PMFORECASTOPTIONS_Type {

    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;
    @XmlElement(name = "ENDDATE", required = true)
    protected DATETIME enddate;
    @XmlElement(name = "BACKFILL", defaultValue = "false")
    protected String backfill;
    @XmlElement(name = "FORWARDFILL", defaultValue = "false")
    protected String forwardfill;

    /**
     * Gets the value of the startdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Sets the value of the startdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

    /**
     * Gets the value of the enddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getENDDATE() {
        return enddate;
    }

    /**
     * Sets the value of the enddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setENDDATE(DATETIME value) {
        this.enddate = value;
    }

    /**
     * Gets the value of the backfill property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBACKFILL() {
        return backfill;
    }

    /**
     * Sets the value of the backfill property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBACKFILL(String value) {
        this.backfill = value;
    }

    /**
     * Gets the value of the forwardfill property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFORWARDFILL() {
        return forwardfill;
    }

    /**
     * Sets the value of the forwardfill property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFORWARDFILL(String value) {
        this.forwardfill = value;
    }

}
